@@ -12,7 +12,6 @@
 #include <stdlib.h>
 #include <netdb.h>
 //#include <sys/types.h>
-//#include <netinet/in.h>
 #ifndef _NETINET_IN_H
 #include <linux/ipv6.h>
 #endif
@@ -21,6 +20,7 @@
 #define s6_addr32              __u6_addr.__u6_addr32
 #define in6_u                  __u6_addr
 #define u6_addr32              __u6_addr32
+#include <netinet/in.h>
 #endif 
 #include "include/modifiedfromkernel/include/net/ipv6-split.h"
 #include "include/modifiedfromkernel/net/ipv6/addrconf-split.c"
@@ -37,7 +37,9 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 	int retval = 1, result, i, cpoints = 0, ccolons = 0;
 	char *addronlystring, *cp, tempstring[NI_MAXHOST];
 	struct in6_addr inet6addr;
-	int compat[4], scope = 0, expecteditems = 0;
+	int scope = 0, expecteditems = 0;
+	int32_t temp[8];
+	int compat[4];
 
 	sprintf(resultstring, "%s", ""); /* clear result string */
 
@@ -107,7 +109,7 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 	if ( ccolons == 6 ) {
 		/* compatv4/mapped format */
 		expecteditems = 10;
-		result = sscanf(tempstring, "%x:%x:%x:%x:%x:%x:%u.%u.%u.%u", &ipv6addrp->addr6[0], &ipv6addrp->addr6[1], &ipv6addrp->addr6[2], &ipv6addrp->addr6[3], &ipv6addrp->addr6[4], &ipv6addrp->addr6[5], &compat[0], &compat[1], &compat[2], &compat[3]);
+		result = sscanf(tempstring, "%x:%x:%x:%x:%x:%x:%d.%d.%d.%d", &temp[0], &temp[1], &temp[2], &temp[3], &temp[4], &temp[5], &compat[0], &compat[1], &compat[2], &compat[3]);
 		/* check compat */
 		for ( i = 0; i <= 3; i++ ) {
 			if ( ( compat[i] < 0 ) || ( compat[i] > 255 ) )	{
@@ -116,13 +118,13 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 				return (retval);
 			};
 		};
-		ipv6addrp->addr6[6] = ( compat[0] << 8 ) | compat[1];
-		ipv6addrp->addr6[7] = ( compat[2] << 8 ) | compat[3];
+		temp[6] = ( compat[0] << 8 ) | compat[1];
+		temp[7] = ( compat[2] << 8 ) | compat[3];
 		scope = IPV6_ADDR_COMPATv4;
 	} else {
 		/* normal format */
 		expecteditems = 8;
-		result = sscanf(tempstring, "%x:%x:%x:%x:%x:%x:%x:%x", &ipv6addrp->addr6[0], &ipv6addrp->addr6[1], &ipv6addrp->addr6[2], &ipv6addrp->addr6[3], &ipv6addrp->addr6[4], &ipv6addrp->addr6[5], &ipv6addrp->addr6[6], &ipv6addrp->addr6[7]);
+		result = sscanf(tempstring, "%x:%x:%x:%x:%x:%x:%x:%x", &temp[0], &temp[1], &temp[2], &temp[3], &temp[4], &temp[5], &temp[6], &temp[7]);
 	};
 	
 #ifdef DEBUG_libipv6calc
@@ -137,12 +139,17 @@ int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6ad
 
 	/* check address words range */
 	for ( i = 0; i <= 7; i++ ) {
-		if ( ( ipv6addrp->addr6[i] < 0x0 ) || ( ipv6addrp->addr6[i] > 0xffff ) )	{
-			sprintf(resultstring, "Error, given address '%s' is not valid on position %d (%x)!", addronlystring, i, ipv6addrp->addr6[i]);
+		if ( ( temp[i] < 0x0 ) || ( temp[i] > 0xffff ) )	{
+			sprintf(resultstring, "Error, given address '%s' is not valid on position %d (%x)!", addronlystring, i, temp[i]);
 			retval = 1;
 			return (retval);
 		};
 	};
+	
+	/* copy into structure */
+	for ( i = 0; i <= 7; i++ ) {
+		ipv6addrp->addr6[i] = temp[i];
+	};
 
 	/* get type of address */
 	for ( i = 0; i < 4; i++ ) {
